@@ -1,5 +1,4 @@
 import io
-from requests.compat import is_py2
 
 
 def coerce_content(content, encoding=None):
@@ -9,8 +8,6 @@ def coerce_content(content, encoding=None):
 
 
 def body_io(string, encoding=None):
-    if is_py2:
-        return io.StringIO(string)
     if hasattr(string, 'encode'):
         string = string.encode(encoding or 'utf-8')
     return io.BytesIO(string)
